@@ -20,11 +20,12 @@ from kivy.cache import Cache
 from kivy.clock import Clock
 from kivy.atlas import Atlas
 from kivy.resources import resource_find
+from kivy.utils import platform
 import zipfile
 try:
-    SIO = __import__('cStringIO')
+    import cStringIO as SIO
 except ImportError:
-    SIO = __import__('StringIO')
+    import StringIO as SIO
 
 
 # late binding
@@ -41,11 +42,11 @@ class ImageData(object):
     The container will always have at least the mipmap level 0.
     '''
 
-    __slots__ = ('fmt', 'mipmaps', 'source')
+    __slots__ = ('fmt', 'mipmaps', 'source', 'flip_vertical')
     _supported_fmts = ('rgb', 'rgba', 'bgr', 'bgra',
             's3tc_dxt1', 's3tc_dxt3', 's3tc_dxt5')
 
-    def __init__(self, width, height, fmt, data, source=None):
+    def __init__(self, width, height, fmt, data, source=None, flip_vertical=True):
         assert fmt in ImageData._supported_fmts
 
         #: Decoded image format, one of a available texture format
@@ -58,6 +59,9 @@ class ImageData(object):
         #: Image source, if available
         self.source = source
 
+        #: Indicate if the texture will need to be vertically flipped
+        self.flip_vertical = flip_vertical
+
     def release_data(self):
         mm = self.mipmaps
         for item in mm.itervalues():
@@ -97,10 +101,10 @@ class ImageData(object):
         return len(self.mipmaps) > 1
 
     def __repr__(self):
-        return '<ImageData width=%d height=%d fmt=%s ' \
-               'source=%r with %d images>' % (
-                self.width, self.height, self.fmt,
-                self.source, len(self.mipmaps))
+        return ('<ImageData width=%d height=%d fmt=%s '
+                'source=%r with %d images>' % (
+                    self.width, self.height, self.fmt,
+                    self.source, len(self.mipmaps)))
 
     def add_mipmap(self, level, width, height, data):
         '''Add a image for a specific mipmap level.
@@ -136,11 +140,12 @@ class ImageLoaderBase(object):
     '''Base to implement an image loader.'''
 
     __slots__ = ('_texture', '_data', 'filename', 'keep_data',
-                '_mipmap')
+                '_mipmap', '_nocache')
 
     def __init__(self, filename, **kwargs):
         self._mipmap = kwargs.get('mipmap', False)
         self.keep_data = kwargs.get('keep_data', False)
+        self._nocache = kwargs.get('nocache', False)
         self.filename = filename
         self._data = self.load(filename)
         self._textures = None
@@ -164,9 +169,13 @@ class ImageLoaderBase(object):
 
             # if not create it and append to the cache
             if texture is None:
+                imagedata = self._data[count]
                 texture = Texture.create_from_data(
-                        self._data[count], mipmap=self._mipmap)
-                Cache.append('kv.texture', uid, texture)
+                        imagedata, mipmap=self._mipmap)
+                if not self._nocache:
+                    Cache.append('kv.texture', uid, texture)
+                if imagedata.flip_vertical:
+                    texture.flip_vertical()
 
             # set as our current texture
             self._textures.append(texture)
@@ -291,7 +300,7 @@ class ImageLoader(object):
                 fn = 'atlas://%s/%s' % (rfn, uid)
                 cid = '%s|%s|%s' % (fn, False, 0)
                 Cache.append('kv.texture', cid, texture)
-                return texture
+                return Image(texture)
 
             # search with resource
             afn = rfn
@@ -309,11 +318,15 @@ class ImageLoader(object):
                 cid = '%s|%s|%s' % (fn, False, 0)
                 #print 'register', cid
                 Cache.append('kv.texture', cid, texture)
-            return atlas[uid]
+            return Image(atlas[uid])
 
         # extract extensions
         ext = filename.split('.')[-1].lower()
 
+        # prevent url querystrings
+        if filename.startswith((('http://', 'https://'))):
+            ext = ext.split('?')[0]
+
         # special case. When we are trying to load a "zip" file with image, we
         # will use the special zip_loader in ImageLoader. This might return a
         # sequence of images contained in the zip.
@@ -363,7 +376,7 @@ class Image(EventDispatcher):
     '''
 
     copy_attributes = ('_size', '_filename', '_texture', '_image',
-                       '_mipmap')
+                       '_mipmap', '_nocache')
 
     def __init__(self, arg, **kwargs):
         # this event should be fired on animation of sequenced img's
@@ -373,6 +386,7 @@ class Image(EventDispatcher):
 
         self._mipmap = kwargs.get('mipmap', False)
         self._keep_data = kwargs.get('keep_data', False)
+        self._nocache = kwargs.get('nocache', False)
         self._size = [0, 0]
         self._image = None
         self._filename = None
@@ -388,6 +402,9 @@ class Image(EventDispatcher):
             for attr in Image.copy_attributes:
                 self.__setattr__(attr, arg.__getattribute__(attr))
         elif type(arg) in (Texture, TextureRegion):
+            if not hasattr(self, 'textures'):
+                self.textures = []
+                self.textures.append(arg)
             self._texture = arg
             self._size = self.texture.size
         elif isinstance(arg, ImageLoaderBase):
@@ -559,7 +576,10 @@ class Image(EventDispatcher):
         if image:
             # we found an image, yeah ! but reset the texture now.
             self.image = image
-            if not image.keep_data and self._keep_data:
+            # if image.__class__ is core image then it's a texture
+            # from atlas or other sources and has no data so skip
+            if (image.__class__ != self.__class__ and
+                not image.keep_data and self._keep_data):
                 self.remove_from_cache()
                 self._filename = ''
                 self._set_filename(value)
@@ -578,7 +598,7 @@ class Image(EventDispatcher):
         tmpfilename = self._filename
         image = ImageLoader.load(
                 self._filename, keep_data=self._keep_data,
-                mipmap=self._mipmap)
+                mipmap=self._mipmap, nocache=self._nocache)
         self._filename = tmpfilename
 
         # put the image into the cache if needed
@@ -623,7 +643,7 @@ class Image(EventDispatcher):
 
         .. warning::
             This function can be used only with images loaded with
-            keep_data=True keyword. For examples ::
+            keep_data=True keyword. For examples::
 
                 m = Image.load('image.png', keep_data=True)
                 color = m.read_pixel(150, 150)
@@ -649,7 +669,7 @@ class Image(EventDispatcher):
         assert data.fmt in ImageData._supported_fmts
         size = 3 if data.fmt in ('rgb', 'bgr') else 4
         index = y * data.width * size + x * size
-        raw = data.data[index:index+size]
+        raw = data.data[index:index + size]
         color = map(lambda c: ord(c) / 255.0, raw)
 
         # conversion for BGR->RGB, BGR->RGBA format
@@ -665,12 +685,15 @@ def load(filename):
 
 
 # load image loaders
-core_register_libs('image', (
+image_libs = []
+if platform() in ('macosx', 'ios'):
+    image_libs += [('imageio', 'img_imageio')]
+image_libs += [
     ('dds', 'img_dds'),
     ('pygame', 'img_pygame'),
     ('pil', 'img_pil'),
-    ('gif', 'img_gif'),
-))
+    ('gif', 'img_gif')]
+core_register_libs('image', image_libs)
 
 # resolve binding.
 from kivy.graphics.texture import Texture, TextureRegion
