@@ -23,6 +23,13 @@ Simple example
 .. include:: ../../examples/widgets/tabbedpanel.py
     :literal:
 
+.. note::
+
+    A new Class :class:`TabbedPanelItem` has been introduced in 1.5.0 for
+    conveniance. So now one can simply add a :class:`TabbedPanelItem` to a
+    :class:`TabbedPanel` and the `content` to the :class:`TabbedPanelItem`
+    like in the example provided above.
+
 Customize the Tabbed Panel
 --------------------------
 
@@ -45,22 +52,33 @@ button::
 
     th.content = your_content_instance
 
-Note: There is one "shared" main content area, active at a given time, for all
+There is one "shared" main content area, active at a given time, for all
 the tabs. Your app is responsible for adding the content of individual tabs,
 and for managing it, but not for doing the content switching. The tabbed panel
 handles switching of the main content object, per user action.
 
-There is always a default tab added when the tabbed panel is instantiated.
+.. note::
+    The default_tab functionality is turned off by default since 1.5.0 to
+    turn it back on set `do_default_tab` = True.
+
+There is a default tab added when the tabbed panel is instantiated.
 Tabs that you add individually as above, are added in addition to the default
 tab. Thus, depending on your needs and design, you will want to customize the
-default tab, including its text::
+default tab::
 
     tp.default_tab_text = 'Something Specific To Your Use'
 
+
 The default tab machinery requires special consideration and management.
 Accordingly, an `on_default_tab` event is provided for associating a callback::
 
-    tp.bind(on_default_tab = my_default_tab_callback)
+    tp.bind(default_tab = my_default_tab_callback)
+
+It's important to note that as by default :data:`default_tab_cls` is of type
+:class:`TabbedPanelHeader` it has the same properties as other tabs.
+
+Since 1.5.0 it is now possible to disable the creation of the
+:data:`default_tab` by setting :data:`do_default_tab` to False
 
 Tabs and content can be removed in several ways::
 
@@ -108,7 +126,7 @@ tabbed panel's background_image and background_color.
 '''
 
 __all__ = ('TabbedPanel', 'TabbedPanelContent', 'TabbedPanelHeader',
-    'TabbedPanelStrip', 'TabbedPanelException')
+           'TabbedPanelItem', 'TabbedPanelStrip', 'TabbedPanelException')
 
 from functools import partial
 from kivy.clock import Clock
@@ -121,7 +139,7 @@ from kivy.uix.gridlayout import GridLayout
 from kivy.uix.floatlayout import FloatLayout
 from kivy.logger import Logger
 from kivy.properties import ObjectProperty, StringProperty, OptionProperty, \
-        ListProperty, NumericProperty, AliasProperty
+    ListProperty, NumericProperty, AliasProperty, BooleanProperty
 
 
 class TabbedPanelException(Exception):
@@ -137,11 +155,11 @@ class TabbedPanelHeader(ToggleButton):
     You can use this TabbedPanelHeader widget to add a new tab to TabbedPanel.
     '''
 
-    content = ObjectProperty(None)
+    content = ObjectProperty(None, allownone=True)
     '''Content to be loaded when this tab header is selected.
 
     :data:`content` is a :class:`~kivy.properties.ObjectProperty` default
-    to None .
+    to None.
     '''
 
     # only allow selecting the tab if not already selected
@@ -154,13 +172,45 @@ class TabbedPanelHeader(ToggleButton):
         else:
             super(TabbedPanelHeader, self).on_touch_down(touch)
 
-    def on_release(self, *l):
-        parent = self.parent
-        while parent is not None and not isinstance(parent, TabbedPanel):
-            parent = parent.parent
-        if not parent:
+    def on_release(self, *largs):
+        # Tabbed panel header is a child of tab_strib which has a
+        # `tabbed_panel` property
+        if self.parent:
+            self.parent.tabbed_panel.switch_to(self)
+
+
+class TabbedPanelItem(TabbedPanelHeader):
+    '''This is a convenience class that provides a header of type
+    TabbedPanelHeader and links it with the content automatically. Thus
+    facilitating you to simply do the following in kv language::
+
+        <TabbedPanel>:
+            ...other settings
+            TabbedPanelItem:
+                BoxLayout:
+                    Label:
+                        text: 'Second tab content area'
+                    Button:
+                        text: 'Button that does nothing'
+
+    .. versionadded:: 1.5.0
+    '''
+
+    def add_widget(self, widget, index=0):
+        self.content = widget
+        if not self.parent:
             return
-        parent.switch_to(self)
+        panel = self.parent.tabbed_panel
+        if panel.current_tab == self:
+            panel.switch_to(self)
+
+    def remove_widget(self, widget):
+        self.content = None
+        if not self.parent:
+            return
+        panel = self.parent.tabbed_panel
+        if panel.current_tab == self:
+            panel.remove_widget(widget)
 
 
 class TabbedPanelStrip(GridLayout):
@@ -210,10 +260,12 @@ class TabbedPanel(GridLayout):
     default to 'atlas://data/images/defaulttheme/tab'.
     '''
 
+    _current_tab = ObjectProperty(None)
+
     def get_current_tab(self):
         return self._current_tab
 
-    current_tab = AliasProperty(get_current_tab, None)
+    current_tab = AliasProperty(get_current_tab, None, bind=('_current_tab', ))
     '''Links to the currently select or active tab.
 
     .. versionadded:: 1.4.0
@@ -221,10 +273,11 @@ class TabbedPanel(GridLayout):
     :data:`current_tab` is a :class:`~kivy.AliasProperty`, read-only.
     '''
 
-    tab_pos = OptionProperty('top_left',
-            options=('left_top', 'left_mid', 'left_bottom', 'top_left',
-                'top_mid', 'top_right', 'right_top', 'right_mid',
-                'right_bottom', 'bottom_left', 'bottom_mid', 'bottom_right'))
+    tab_pos = OptionProperty(
+        'top_left',
+        options=('left_top', 'left_mid', 'left_bottom', 'top_left',
+                 'top_mid', 'top_right', 'right_top', 'right_mid',
+                 'right_bottom', 'bottom_left', 'bottom_mid', 'bottom_right'))
     '''Specifies the position of the tabs relative to the content.
     Can be one of: `left_top`, `left_mid`, `left_bottom`, `top_left`,
     `top_mid`, `top_right`, `right_top`, `right_mid`, `right_bottom`,
@@ -234,20 +287,29 @@ class TabbedPanel(GridLayout):
     default to 'bottom_mid'.
     '''
 
-    tab_height = NumericProperty(40)
+    tab_height = NumericProperty('40dp')
     '''Specifies the height of the tab header.
 
     :data:`tab_height` is a :class:`~kivy.properties.NumericProperty`,
     default to 40.
     '''
 
-    tab_width = NumericProperty(100, allownone=True)
+    tab_width = NumericProperty('100dp', allownone=True)
     '''Specifies the width of the tab header.
 
     :data:`tab_width` is a :class:`~kivy.properties.NumericProperty`,
     default to 100.
     '''
 
+    do_default_tab = BooleanProperty(True)
+    '''Specifies weather a default_tab head is provided.
+
+    .. versionadded:: 1.5.0
+
+    :data:`do_default_tab` is a :class:`~kivy.properties.BooleanProperty`,
+    defaults to 'True'.
+    '''
+
     default_tab_text = StringProperty('Default tab')
     '''Specifies the text displayed on the default tab header.
 
@@ -280,12 +342,17 @@ class TabbedPanel(GridLayout):
     '''
 
     content = ObjectProperty(None)
-    '''This is the object holding the content of the current tab.
+    '''This is the object holding(current_tab's content is added to this)
+    the content of the current tab. To Listen to the changes in the content
+    of the current tab you should bind to `current_tab` and then access it's
+    `content` property.
 
     :data:`content` is a :class:`~kivy.properties.ObjectProperty`,
     default to 'None'.
     '''
 
+    _default_tab = ObjectProperty(None)
+
     def get_def_tab(self):
         return self._default_tab
 
@@ -297,17 +364,19 @@ class TabbedPanel(GridLayout):
             return
         oltab = self._default_tab
         self._default_tab = new_tab
-        if hasattr(self, '_original_tab') and self._original_tab == oltab:
-            self.remove_widget(oltab)
-            self._original_tab = None
+        self.remove_widget(oltab)
+        self._original_tab = None
         self.switch_to(new_tab)
         new_tab.state = 'down'
 
-    default_tab = AliasProperty(get_def_tab, set_def_tab)
+    default_tab = AliasProperty(get_def_tab, set_def_tab,
+                                bind=('_default_tab', ))
     '''Holds the default tab.
 
-    .. Note:: For convenience, the automatically provided default tab is deleted
-              when you change default_tab to something else.
+    .. Note:: For convenience, the automatically provided default tab is
+              deleted when you change default_tab to something else.
+              As of 1.5.0 This behaviour has been extended to every
+              `default_tab` for consistency not just the auto provided one.
 
     :data:`default_tab` is a :class:`~kivy.properties.AliasProperty`
     '''
@@ -319,38 +388,168 @@ class TabbedPanel(GridLayout):
         self.default_tab.content = l[0]
 
     default_tab_content = AliasProperty(get_def_tab_content,
-        set_def_tab_content)
+                                        set_def_tab_content)
     '''Holds the default tab content.
 
     :data:`default_tab_content` is a :class:`~kivy.properties.AliasProperty`
     '''
 
     def __init__(self, **kwargs):
+        # these variables need to be initialised before the kv lang is
+        # processed setup the base layout for the tabbed panel
         self._tab_layout = GridLayout(rows=1)
+        self.rows = 1
+        # bakground_image
         self._bk_img = Image(
             source=self.background_image, allow_stretch=True,
             keep_ratio=False, color=self.background_color)
-        self._tab_strip = _tabs = TabbedPanelStrip(tabbed_panel=self,
+
+        self._tab_strip = TabbedPanelStrip(
+            tabbed_panel=self,
             rows=1, cols=99, size_hint=(None, None),
             height=self.tab_height, width=self.tab_width)
 
         self._partial_update_scrollview = None
-        self.content = content = TabbedPanelContent()
-
-        self._current_tab = default_tab = self._original_tab \
+        self.content = TabbedPanelContent()
+        self._current_tab = self._original_tab \
             = self._default_tab = TabbedPanelHeader()
+
         super(TabbedPanel, self).__init__(**kwargs)
 
+        self.bind(size=self._reposition_tabs)
+        if not self.do_default_tab:
+            Clock.schedule_once(self._switch_to_first_tab)
+            return
+        self._setup_default_tab()
+        self.switch_to(self.default_tab)
+
+    def switch_to(self, header):
+        '''Switch to a specific panel header.
+        '''
+        header_content = header.content
+        self._current_tab.state = 'normal'
+        header.state = 'down'
+        self._current_tab = header
+        self.clear_widgets()
+        if header_content is None:
+            return
+        # if content has a previous parent remove it from that parent
+        parent = header_content.parent
+        if parent:
+            parent.remove_widget(header_content)
+        self.add_widget(header_content)
+
+    def clear_tabs(self, *l):
+        self_tabs = self._tab_strip
+        self_tabs.clear_widgets()
+        if self.do_default_tab:
+            self_default_tab = self._default_tab
+            self_tabs.add_widget(self_default_tab)
+            self_tabs.width = self_default_tab.width
+        self._reposition_tabs()
+
+    def add_widget(self, widget, index=0):
+        content = self.content
+        if content is None:
+            return
+        parent = widget.parent
+        if parent:
+            parent.remove_widget(widget)
+        if widget in (content, self._tab_layout):
+            super(TabbedPanel, self).add_widget(widget, index)
+        elif isinstance(widget, TabbedPanelHeader):
+            self_tabs = self._tab_strip
+            self_tabs.add_widget(widget)
+            widget.group = '__tab%r__' % self_tabs.uid
+            self.on_tab_width()
+        else:
+            widget.pos_hint = {'x': 0, 'top': 1}
+            content.add_widget(widget, index)
+
+    def remove_widget(self, widget):
+        content = self.content
+        if content is None:
+            return
+        if widget in (content, self._tab_layout):
+            super(TabbedPanel, self).remove_widget(widget)
+        elif isinstance(widget, TabbedPanelHeader):
+            if widget != self._default_tab:
+                self_tabs = self._tab_strip
+                self_tabs.width -= widget.width
+                self_tabs.remove_widget(widget)
+                if widget.state == 'down':
+                    if self.do_default_tab:
+                        self._default_tab.on_release()
+                self._reposition_tabs()
+            else:
+                Logger.info('TabbedPanel: default tab! can\'t be removed.\n' +
+                            'Change `default_tab` to a different tab.')
+        else:
+            if widget in content.children:
+                content.remove_widget(widget)
+
+    def clear_widgets(self, **kwargs):
+        content = self.content
+        if content is None:
+            return
+        if kwargs.get('do_super', False):
+            super(TabbedPanel, self).clear_widgets()
+        else:
+            content.clear_widgets()
+
+    def on_background_image(self, *l):
+        self._bk_img.source = self.background_image
+
+    def on_background_color(self, *l):
+        if self.content is None:
+            return
+        self._bk_img.color = self.background_color
+
+    def on_do_default_tab(self, instance, value):
+        if not value:
+            dft = self.default_tab
+            if dft in self.tab_list:
+                self._default_tab = None
+                self.remove_widget(dft)
+                self._switch_to_first_tab()
+        else:
+            self._current_tab.state = 'normal'
+            self._setup_default_tab()
+
+    def on_default_tab_text(self, *args):
+        self._default_tab.text = self.default_tab_text
+
+    def on_tab_width(self, *l):
+        Clock.unschedule(self._update_tab_width)
+        Clock.schedule_once(self._update_tab_width, 0)
+
+    def on_tab_height(self, *l):
+        self._tab_layout.height = self._tab_strip.height = self.tab_height
+        self._reposition_tabs()
+
+    def on_tab_pos(self, *l):
+        # ensure canvas
+        self._reposition_tabs()
+
+    def _setup_default_tab(self):
+        if self._default_tab in self.tab_list:
+            return
         content = self._default_tab.content
+        _tabs = self._tab_strip
         cls = self.default_tab_cls
+
         if not issubclass(cls, TabbedPanelHeader):
             raise TabbedPanelException('`default_tab_class` should be\
                 subclassed from `TabbedPanelHeader`')
 
-        if cls != type(default_tab):
-            self._default_tab = cls()
+        # no need to instanciate if class is TabbedPanelHeader
+        if cls != TabbedPanelHeader:
+            self._current_tab = self._original_tab = self._default_tab = cls()
+
         default_tab = self.default_tab
-        default_tab.text = self.default_tab_text
+        if self._original_tab == self.default_tab:
+            default_tab.text = self.default_tab_text
+
         default_tab.height = self.tab_height
         default_tab.group = '__tab%r__' % _tabs.uid
         default_tab.state = 'down'
@@ -367,124 +566,23 @@ class TabbedPanel(GridLayout):
         else:
             Clock.schedule_once(self._load_default_tab_content)
         self._current_tab = default_tab
-        self.on_tab_pos()
+
+    def _switch_to_first_tab(self, *l):
+        ltl = len(self.tab_list) - 1
+        if ltl > -1:
+            self._current_tab = dt = self._original_tab \
+                = self.tab_list[ltl]
+            self.switch_to(dt)
 
     def _load_default_tab_content(self, dt):
-        self.switch_to(self.default_tab)
+        if self.default_tab:
+            self.switch_to(self.default_tab)
 
-    def on_default_tab_text(self, *args):
-        self._default_tab.text = self.default_tab_text
+    def _reposition_tabs(self, *l):
+        Clock.unschedule(self._update_tabs)
+        Clock.schedule_once(self._update_tabs, 0)
 
-    def switch_to(self, header):
-        '''Switch to a specific panel header.
-        '''
-        header_content = header.content
-        self._current_tab = header
-        self.clear_widgets()
-        if header_content is None:
-            return
-        # if content has a previous parent remove it from that parent
-        parent = header_content.parent
-        if parent:
-            parent.remove_widget(header_content)
-        self.add_widget(header_content)
-
-    def add_widget(self, widget, index=0):
-        content = self.content
-        if content is None:
-            return
-        parent = widget.parent
-        if widget.parent:
-            parent.remove_widget(widget)
-        if widget == content or widget == self._tab_layout:
-            super(TabbedPanel, self).add_widget(widget, index)
-        elif isinstance(widget, TabbedPanelHeader):
-            self_tabs = self._tab_strip
-            self_tabs.add_widget(widget)
-            widget.group = '__tab%r__' % self_tabs.uid
-            self.on_tab_width()
-        else:
-            widget.pos_hint = {'x': 0, 'top': 1}
-            content.add_widget(widget, index)
-
-    def remove_widget(self, widget):
-        content = self.content
-        if content is None:
-            return
-        if widget == content or widget == self._tab_layout:
-            super(TabbedPanel, self).remove_widget(widget)
-        elif isinstance(widget, TabbedPanelHeader):
-            if widget != self._default_tab:
-                self_tabs = self._tab_strip
-                self_tabs.width -= widget.width
-                self_tabs.remove_widget(widget)
-                if widget.state == 'down':
-                    self._default_tab.on_release()
-                self.reposition_tabs()
-            else:
-                Logger.info('TabbedPanel: default tab! can\'t be removed.\n' +
-                    'Change `default_tab` to a different tab.')
-        else:
-            content.remove_widget(widget)
-
-    def clear_widgets(self, **kwargs):
-        content = self.content
-        if content is None:
-            return
-        if kwargs.get('do_super', False):
-            super(TabbedPanel, self).clear_widgets()
-        else:
-            content.clear_widgets()
-
-    def clear_tabs(self, *l):
-        self_tabs = self._tab_strip
-        self_tabs.clear_widgets()
-        self_default_tab = self._default_tab
-        self_tabs.add_widget(self_default_tab)
-        self_tabs.width = self_default_tab.width
-        self.reposition_tabs()
-
-    def reposition_tabs(self, *l):
-        Clock.unschedule(self.on_tab_pos)
-        Clock.schedule_once(self.on_tab_pos, 0)
-
-    def on_background_image(self, *l):
-        self._bk_img.source = self.background_image
-
-    def on_background_color(self, *l):
-        if self.content is None:
-            return
-        self._bk_img.color = self.background_color
-
-    def on_tab_width(self, *l):
-        Clock.unschedule(self.update_tab_width)
-        Clock.schedule_once(self.update_tab_width, 0)
-
-    def update_tab_width(self, *l):
-        if self.tab_width:
-            for tab in self.tab_list:
-                tab.size_hint_x = 1
-            tsw = self.tab_width * len(self._tab_strip.children)
-        else:
-            # tab_width = None
-            tsw = 0
-            for tab in self.tab_list:
-                if tab.size_hint_x:
-                    # size_hint_x: x/.xyz
-                    tab.size_hint_x = 1
-                    #drop to default tab_width
-                    tsw += 100
-                else:
-                    # size_hint_x: None
-                    tsw += tab.width
-        self._tab_strip.width = tsw
-        self.reposition_tabs()
-
-    def on_tab_height(self, *l):
-        self._tab_layout.height = self._tab_strip.height = self.tab_height
-        self.reposition_tabs()
-
-    def on_tab_pos(self, *l):
+    def _update_tabs(self, *l):
         self_content = self.content
         if not self_content:
             return
@@ -555,7 +653,8 @@ class TabbedPanel(GridLayout):
             self.cols = 2
             self.rows = 1
             # tab_layout contains two blank dummy widgets for spacing
-            #"vertically" and the scatter containing scrollview containing tabs
+            # "vertically" and the scatter containing scrollview
+            # containing tabs
             tab_layout.rows = 3
             tab_layout.cols = 1
             tab_layout.size_hint = (None, 1)
@@ -566,12 +665,12 @@ class TabbedPanel(GridLayout):
             # rotate the scatter for vertical positions
             rotation = 90 if tab_pos[0] == 'l' else -90
             sctr = Scatter(do_translation=False,
-                    rotation=rotation,
-                    do_rotation=False,
-                    do_scale=False,
-                    size_hint=(None, None),
-                    auto_bring_to_front=False,
-                    size=scrl_v.size)
+                           rotation=rotation,
+                           do_rotation=False,
+                           do_scale=False,
+                           size_hint=(None, None),
+                           auto_bring_to_front=False,
+                           size=scrl_v.size)
             sctr.add_widget(scrl_v)
 
             lentab_pos = len(tab_pos)
@@ -591,7 +690,7 @@ class TabbedPanel(GridLayout):
             elif tab_pos[lentab_pos - 4:] == '_mid':
                 #calculate top of scatter
                 sctr.bind(pos=partial(self._update_top, sctr, 'mid',
-                    scrl_v.width))
+                                      scrl_v.width))
                 tab_list = (Widget(), sctr, Widget())
             elif tab_pos[lentab_pos - 7:] == '_bottom':
                 tab_list = (Widget(), Widget(), sctr)
@@ -611,10 +710,31 @@ class TabbedPanel(GridLayout):
         for widg in widget_list:
             add(widg)
 
+    def _update_tab_width(self, *l):
+        if self.tab_width:
+            for tab in self.tab_list:
+                tab.size_hint_x = 1
+            tsw = self.tab_width * len(self._tab_strip.children)
+        else:
+            # tab_width = None
+            tsw = 0
+            for tab in self.tab_list:
+                if tab.size_hint_x:
+                    # size_hint_x: x/.xyz
+                    tab.size_hint_x = 1
+                    #drop to default tab_width
+                    tsw += 100
+                else:
+                    # size_hint_x: None
+                    tsw += tab.width
+        self._tab_strip.width = tsw
+        self._reposition_tabs()
+
     def _update_top(self, *args):
         sctr, top, scrl_v_width, x, y = args
         Clock.unschedule(partial(self._updt_top, sctr, top, scrl_v_width))
-        Clock.schedule_once(partial(self._updt_top, sctr, top, scrl_v_width), 0)
+        Clock.schedule_once(
+            partial(self._updt_top, sctr, top, scrl_v_width), 0)
 
     def _updt_top(self, sctr, top, scrl_v_width, *args):
         if top[0] == 't':
